@@ -20,16 +20,29 @@
 
 .. moduleauthor:: Luke Macken <lmacken@redhat.com>
 .. moduleauthor:: Toshio Kuratomi <tkuratom@redhat.com>
+.. moduleauthor:: Ralph Bean <rbean@redhat.com>
 '''
 
 import os
 import stat
 from os import path
 import logging
-import cPickle as pickle
-import Cookie
 import warnings
 
+
+try:
+    import cPickle as pickle
+except:
+    # Python3 support
+    import pickle
+
+try:
+    import Cookie
+except ImportError:
+    # Python3 support
+    import http.cookies as Cookie
+
+
 from kitchen.text.converters import to_bytes
 
 from fedora import __version__
@@ -37,7 +50,7 @@ from fedora import __version__
 log = logging.getLogger(__name__)
 
 b_SESSION_DIR = path.join(path.expanduser('~'), '.fedora')
-b_SESSION_FILE = path.join(b_SESSION_DIR, '.fedora_session')
+b_SESSION_FILE = path.join(b_SESSION_DIR, 'fedora_session')
 
 from fedora.client import AuthError, ProxyClient
 
@@ -115,13 +128,11 @@ class BaseClient(ProxyClient):
         session_file = None
         if path.isfile(b_SESSION_FILE):
             try:
-                session_file = file(b_SESSION_FILE, 'r')
-                saved_session = pickle.load(session_file)
+                with open(b_SESSION_FILE, 'rb') as session_file:
+                    saved_session = pickle.load(session_file)
             except (IOError, EOFError):
                 self.log.info('Unable to load session from %(file)s' %
                               {'file': b_SESSION_FILE})
-            if session_file:
-                session_file.close()
 
         return saved_session
 
@@ -133,16 +144,15 @@ class BaseClient(ProxyClient):
         # Make sure the directory exists
         if not path.isdir(b_SESSION_DIR):
             try:
-                os.mkdir(b_SESSION_DIR, 0755)
-            except OSError, e:
+                os.mkdir(b_SESSION_DIR, 0o755)
+            except OSError as e:
                 self.log.warning('Unable to create %(dir)s: %(error)s' %
                                  {'dir': b_SESSION_DIR, 'error': to_bytes(e)})
 
         try:
-            session_file = file(b_SESSION_FILE, 'w')
-            os.chmod(b_SESSION_FILE, stat.S_IRUSR | stat.S_IWUSR)
-            pickle.dump(save, session_file)
-            session_file.close()
+            with open(b_SESSION_FILE, 'wb') as session_file:
+                os.chmod(b_SESSION_FILE, stat.S_IRUSR | stat.S_IWUSR)
+                pickle.dump(save, session_file)
         except Exception as e:  # pylint: disable-msg=W0703
             # If we can't save the file, issue a warning but go on.  The
             # session just keeps you from having to type your password over
